@@ -4,13 +4,13 @@ from wtforms.form import FormMeta
 from wtforms_alchemy import (
     model_form_factory,
     model_form_meta_factory,
-    ModelFormMeta
+    ModelFormMeta,
 )
 
 
 class _MetaWithInit(FormMeta):
     def __init__(cls, *args, **kwargs):
-        cls.test_attr = 'SomeVal'
+        cls.test_attr = "SomeVal"
         FormMeta.__init__(cls, *args, **kwargs)
 
 
@@ -18,7 +18,7 @@ MetaWithInit = model_form_meta_factory(_MetaWithInit)
 
 
 class _MetaWithoutInit(FormMeta):
-    test_attr = 'SomeVal'
+    test_attr = "SomeVal"
 
 
 MetaWithoutInit = model_form_meta_factory(_MetaWithoutInit)
