@@ -5,14 +5,14 @@ from tests import MultiDict
 from wtforms_alchemy import null_or_unicode
 
 
-class TestSelectField(object):
+class TestSelectField:
     def test_understands_none_values(self):
         class MyForm(Form):
             choice_field = SelectField(
-                choices=[('', '-- Choose --'), ('choice 1', 'Something')],
-                coerce=null_or_unicode
+                choices=[("", "-- Choose --"), ("choice 1", "Something")],
+                coerce=null_or_unicode,
             )
 
-        form = MyForm(MultiDict({'choice_field': u''}))
+        form = MyForm(MultiDict({"choice_field": ""}))
         form.validate()
         assert form.errors == {}
