@@ -4,8 +4,8 @@ from wtforms_alchemy import ModelForm
 
 class TestFieldParameters(ModelFormTestCase):
     def test_assigns_description_from_column_info(self):
-        self.init(info={'description': 'Description'})
-        self.assert_description('test_column', 'Description')
+        self.init(info={"description": "Description"})
+        self.assert_description("test_column", "Description")
 
     def test_assigns_descriptions_from_form_configuration(self):
         self.init()
@@ -14,9 +14,7 @@ class TestFieldParameters(ModelFormTestCase):
             class Meta:
                 model = self.ModelTest
 
-                field_args = {
-                    'test_column': {'description': 'TESTING'}
-                }
+                field_args = {"test_column": {"description": "TESTING"}}
 
         self.form_class = ModelTestForm
-        self.assert_description('test_column', 'TESTING')
+        self.assert_description("test_column", "TESTING")
